@@ -123,25 +123,38 @@ static tpm2_option_code tss2_handle_options (
                 fprintf (stderr, "Not enough memory\n");
                 goto out;
             }
-            char *fapi_version;
-            TSS2_RC ret = Fapi_GetInfo(fctx, &fapi_version);
+            char *info;
+            TSS2_RC ret = Fapi_GetInfo(fctx, &info);
             if (ret != TSS2_RC_SUCCESS) {
                 fprintf (stderr, "Fapi_GetInfo returned %u\n", ret);
                 free(prog_name);
                 goto out;
             }
-            char* target = strndup(fapi_version, 50); // TODO: Extract correct version
-            /* N.B. the returned version is UTF-8 and printing it correct
-             * depends on the locale */
-            Fapi_Free(fapi_version);
-            printf ("%s from " PACKAGE " version " VERSION " using at run time "
-                    "FAPI library version %s.\nCopyright (C) 2019 Fraunhofer SI"
-                    "T.\nLicense BSD-3-Clause.\nMy homepage is https://github.com/tpm2"
-                    "-software/tpm2-tools .  The homepage of the FAPI library i"
-                    "s https://github.com/tpm2-software/tpm2-tss .\n",
-                    basename (prog_name), target /*fapi_version*/);
+
+            char *version = NULL;
+            char *t = strstr(info, "\"version\"");
+            if (t) {
+                t = t + strlen("\"version\"");
+                ret = sscanf(t, "%*[^\"]\"%m[^\"]%*[*]", &version);
+                /* Version string is not larger than 128 characters */
+                if (ret!=1 || strlen(version) > 128 ) {
+                    free(version);
+                    version = "not found";
+                    t = NULL;
+                }
+            }
+            else{
+                version = "not found";
+            }
+            Fapi_Free(info);
+
+            printf("tool=\"%s\" version=\"%s\" fapi-version=\"%s\"\n",
+                basename (prog_name), VERSION, version);
+
             free(prog_name);
-            free(target);
+            if (t) {
+                free(version);
+            }
             }
             rc = tpm2_option_code_stop;
             goto out;
@@ -361,13 +374,18 @@ free_opts:
 
 int open_write_and_close(const char* path, bool overwrite, const void *output,
     size_t output_len) {
-    size_t length = output_len ? output_len : strlen (output);
+
+    size_t length = 0;
+
+    if (output_len) {
+        length = output_len;
+    }
+
     if (!path || !strcmp(path, "-")) {
         if (-1 == write (STDOUT_FILENO, output, length)) {
             fprintf (stderr, "write(2) to stdout failed: %m\n");
             return 1;
         }
-        putchar ('\n');
         return 0;
     }
 
